@@ -73,13 +73,12 @@ namespace tremotesf {
         if (mFilesModel) {
             mFilesModel->load(url);
         }
-    }
 
-    QSize AddTorrentDialog::sizeHint() const {
+        QSize size(448, 0);
         if (mMode == Mode::File) {
-            return minimumSizeHint().expandedTo(QSize(448, 512));
+            size.setHeight(512);
         }
-        return minimumSizeHint().expandedTo(QSize(448, 0));
+        resize(sizeHint().expandedTo(size));
     }
 
     void AddTorrentDialog::accept() {
@@ -279,14 +278,14 @@ namespace tremotesf {
         if (mMode == Mode::File) {
             mTorrentFilesView = new TorrentFilesView(mFilesModel, mRpc);
             layout->insertRow(rowForWidget(layout, freeSpaceLabel) + 1, mTorrentFilesView);
+        } else {
+            layout->addItem(new QSpacerItem(0, 0, QSizePolicy::Minimum, QSizePolicy::Expanding));
         }
 
         mDialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
         QObject::connect(mDialogButtonBox, &QDialogButtonBox::accepted, this, &AddTorrentDialog::accept);
         QObject::connect(mDialogButtonBox, &QDialogButtonBox::rejected, this, &AddTorrentDialog::reject);
-        layout->addWidget(mDialogButtonBox);
-
-        setMinimumSize(minimumSizeHint());
+        layout->addRow(mDialogButtonBox);
 
         const auto updateUi = [=, this] {
             const bool enabled = mRpc->isConnected() && (mFilesModel ? mFilesModel->isLoaded() : true);
@@ -298,7 +297,10 @@ namespace tremotesf {
             }
 
             for (int i = 1, max = layout->count(); i < max; ++i) {
-                layout->itemAt(i)->widget()->setEnabled(enabled);
+                auto* const widget = layout->itemAt(i)->widget();
+                if (widget) {
+                    widget->setEnabled(enabled);
+                }
             }
 
             mAddTorrentParametersWidgets.startTorrentCheckBox->setEnabled(enabled);
