@@ -154,6 +154,7 @@ namespace tremotesf {
     ServerEditDialog::ServerEditDialog(ServersModel* serversModel, int row, QWidget* parent)
         : QDialog(parent), mServersModel(serversModel) {
         setupUi();
+        resize(sizeHint().expandedTo(QSize(384, 512)));
 
         if (row == -1) {
             //: Dialog title
@@ -215,8 +216,6 @@ namespace tremotesf {
         setProxyFieldsVisible();
     }
 
-    QSize ServerEditDialog::sizeHint() const { return QDialog::sizeHint().expandedTo(QSize(384, 512)); }
-
     void ServerEditDialog::accept() {
         if (mServersModel) {
             const QString newName(mNameLineEdit->text());
@@ -461,8 +460,6 @@ namespace tremotesf {
         QObject::connect(mDialogButtonBox, &QDialogButtonBox::accepted, this, &ServerEditDialog::accept);
         QObject::connect(mDialogButtonBox, &QDialogButtonBox::rejected, this, &ServerEditDialog::reject);
         topLayout->addWidget(mDialogButtonBox);
-
-        setMinimumSize(minimumSizeHint());
     }
 
     void ServerEditDialog::setProxyFieldsVisible() {
