@@ -161,6 +161,7 @@ namespace tremotesf {
         const auto currentServerName = Servers::instance()->currentServerName();
         for (const auto& server : servers) {
             auto* const action = menu->addAction(server.name);
+            action->setData(server.name);
             action->setCheckable(true);
             group->addAction(action);
             if (server.name == currentServerName) {
@@ -176,7 +177,7 @@ namespace tremotesf {
             if (action == connectionSettingsAction) {
                 emit showConnectionSettingsDialog();
             } else {
-                const auto selectedName = action->text();
+                const auto selectedName = action->data().toString();
                 const auto servers = Servers::instance()->servers();
                 const auto found = std::find_if(servers.begin(), servers.end(), [&](const auto& server) {
                     return server.name == selectedName;
