@@ -53,8 +53,9 @@ namespace tremotesf {
         setWindowTitle(qApp->translate("tremotesf", "Server Options"));
 
         setupUi();
+        resize(sizeHint().expandedTo(QSize(700, 550)));
 
-        QObject::connect(mRpc, &Rpc::connectedChanged, this, [=, this] {
+        const auto onConnectedChanged = [this] {
             if (mRpc->isConnected()) {
                 mDisconnectedMessageWidget->animatedHide();
                 mDisconnectedMessageWidget->setEnabled(true);
@@ -73,13 +74,13 @@ namespace tremotesf {
                 mSpeedPageWidget->setEnabled(false);
                 mNetworkPageWidget->setEnabled(false);
             }
-        });
+        };
+        QObject::connect(mRpc, &Rpc::connectedChanged, this, onConnectedChanged);
+        onConnectedChanged();
 
         loadSettings();
     }
 
-    QSize ServerSettingsDialog::sizeHint() const { return minimumSizeHint().expandedTo(QSize(700, 550)); }
-
     void ServerSettingsDialog::accept() {
         ServerSettings* settings = mRpc->serverSettings();
 
@@ -142,6 +143,7 @@ namespace tremotesf {
         //
 
         auto layout = new QVBoxLayout(this);
+        layout->setContentsMargins(0, 0, 0, 0);
 
         //: Message that appears when disconnected from server
         mDisconnectedMessageWidget = new KMessageWidget(qApp->translate("tremotesf", "Disconnected"), this);
@@ -558,9 +560,7 @@ namespace tremotesf {
         auto dialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
         QObject::connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &ServerSettingsDialog::accept);
         QObject::connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &ServerSettingsDialog::reject);
-        layout->addWidget(dialogButtonBox);
-
-        setMinimumSize(minimumSizeHint());
+        pageWidget->setPageFooter(dialogButtonBox);
     }
 
     void ServerSettingsDialog::loadSettings() {
